#!/bin/bash
# Realizzato da Giovanni Ubaldi (www.ubaweb.it) il 18/02/2012
# Salva la schermata della finestra scelta come:
# screen_0.png, screen_1.png, ...screen_n.png
# e mostra l'immagine salvata in eog o nel programma impostato
# IMPOSTAZIONI
# Il tipo di immagine può essere impostato alla riga:13
# Il percorso di salvataggio può essere impostato alla riga:14
# Il programma da usare per aprire l'immagine ottenuta si imposta alla riga:15

reset

tipoImg="png"	# formato (supportato da imagemagick png, jpg, gif, bmp,...)
dirSalvataggio=~/Schermate_xwd	# directory in cui salvare i file convertiti
prog="eog"			# programma con cui aprire il file convertito (eog, gimp,..)

# controllo che il progamma impostato sia installato
pathProg=$(which $prog)
if [ -n "$pathProg"  ]	# -n significa frase non nulla (il contrario di -z)
	then
	prog=$pathProg
	else
	echo "Spiacente! Il programma \"$prog\" non sembra istallato!"
	echo "Cambiarlo nelle impostazioni o istallarlo!"
	exit 1
fi

xwd -out temp		# creo il file temporaneo della la schermata 
					# (leggibile con: xwud -screen -in nomeDelFileimmagine)
					
# se la directory di salvataggio non esiste la creo con i permessi completi
if [ ! -d $dirSalvataggio ]
	then
		mkdir -m a=rwx $dirSalvataggio
fi

if [ -e temp ]	# Se il file "temp" è stato creato
	then
		# conto il numero di file con nome del tipo: screen*.png
		n=$(ls $dirSalvataggio/screen*.$tipoImg 2> /dev/null | wc -l)
		# costruisco in nome del file con numero progressivo
		nomeFileProgr="$dirSalvataggio/screen_$n.$tipoImg"
		# effettuo la conversione (con convert di imagemagick)
		convert temp $nomeFileProgr								
		# eliminino il file temporaneo crato da xwd
		rm temp													
		echo -e "\nOk! Salvato in $dirSalvataggio\n"	# messaggio di successo
		$prog $nomeFileProgr &	# mostro l'immagine con il programma impostato
		exit 0
	else
		echo "Attenzione! Il file temporaneo non è stato creato."
fi


